@@ -18,6 +18,34 @@ test_that("cultivar", {
     new_wheat2 <- search_path(new_wheat, "[Structure].HeightModel.WaterStress.XYPairs")
     expect_equal(length(new_wheat2), 2)
     expect_equal(new_wheat2$node$X[[1]], "0.4")
+
+    new_wheat <- set_parameter_value(wheat,
+                                     "[Structure].HeightModel.WaterStress.XYPairs.X", "0.4, 1.1")
+    new_wheat2 <- search_path(new_wheat, "[Structure].HeightModel.WaterStress.XYPairs")
+    expect_equal(length(new_wheat2), 2)
+    expect_equal(new_wheat2$node$X[[1]], "0.4")
+
+    new_wheat <- set_parameter_value(wheat,
+                                     "[Structure].HeightModel.WaterStress.XYPairs.X", "0.4 , 1.1")
+    new_wheat2 <- search_path(new_wheat, "[Structure].HeightModel.WaterStress.XYPairs")
+    expect_equal(length(new_wheat2), 2)
+    expect_equal(new_wheat2$node$X[[1]], "0.4")
+
+    new_wheat <- set_parameter_value(wheat,
+                                     "[Structure].HeightModel.WaterStress.XYPairs.X", "0.4 ,1.1")
+    new_wheat2 <- search_path(new_wheat, "[Structure].HeightModel.WaterStress.XYPairs")
+    expect_equal(length(new_wheat2), 2)
+    expect_equal(new_wheat2$node$X[[1]], "0.4")
+
+    expect_error({
+        new_wheat <- set_parameter_value(wheat,
+                                     "[Structure].HeightModel.WaterStress.XYPairs.X", "0.4")
+        new_wheat <- set_parameter_value(wheat,
+                                         "[Structure].HeightModel.WaterStress.XYPairs.X", "0.4,1.1,2")
+
+    })
+
+
     new_wheat <- set_parameter_value(
         wheat,
         "[Structure].HeightModel.WaterStress.XYPairs.Y", "0.1,1.1")
@@ -25,6 +53,13 @@ test_that("cultivar", {
     expect_equal(length(new_wheat2), 2)
     expect_equal(new_wheat2$node$Y[[2]], "1.1")
 
+    new_wheat <- set_parameter_value(
+        wheat,
+        "[Structure].CohortInitialisationStage", "Germination1")
+    new_wheat2 <- search_path(new_wheat, "[Structure]")
+    expect_equal(length(new_wheat2), 2)
+    expect_equal(new_wheat2$node$CohortInitialisationStage, "Germination1")
+
     expect_error({
         new_wheat <- set_parameter_value(
             wheat,
